@@ -1,9 +1,10 @@
 import os
 import numpy as np
-from supervised_learning import SupervisedLearnerPrimitiveBase
-from tian_STMB_new import STMB
+# from supervised_learning import SupervisedLearnerPrimitiveBase
+# from tian_STMB_new import STMB
+from stmb_tools import *
 
-class STMBFeatureSelector(SupervisedLearnerPrimitiveBase):
+class STMBFeatureSelector():
     """
     This class implements a feature selection method:
 
@@ -27,7 +28,7 @@ class STMBFeatureSelector(SupervisedLearnerPrimitiveBase):
     """
 
     def __init__(self):
-        super(SupervisedLearnerPrimitiveBase, self).__init__()
+        # super(SupervisedLearnerPrimitiveBase, self).__init__()
 
         self.is_feature_selection = True
         self.hyperparameters = {}
